-------------------------------------------------
-- For a verbose description of the following, --
-- see http://wiki.interfaceware.com/640.html  --
-------------------------------------------------

require 'dicom'

function main()
   
   -- Loading DICOM Files
   
   local user = 'admin'  -- *** USE YOUR USERNAME HERE ***
   local d = dicom.load('edit/'..user..'/other/sample.dcm')
   
   -- Modify Existing Values without Changing VRs
   
   print(d.AcquisitionNumber.value)
   d.AcquisitionNumber.value = 10
   print(d.AcquisitionNumber.value)
   
   -- Modify or Create Elements with Default VR
   
   d.AcquisitionNumber = 20  -- Omit .value part.
   print(d.AcquisitionNumber.value)
   
   -- Modify or Create Elements with Specific VR
   
   print(d.AcquisitionNumber.vr)
   d.AcquisitionNumber = { value=2, vr='SS' }
   print(d.AcquisitionNumber.value)
   print(d.AcquisitionNumber.vr)
   
   -- Modify VR without Changing Value
   
   d.AcquisitionNumber.vr = 'IS'
   print(d.AcquisitionNumber.value)
   
   -- Examining Multiple Values (when VM > 1)
   
   local function values(dcm)
      return dcm.value:gmatch('[^\\]+')
   end
   
   print(d.ImageOrientationPatient.value)
   print(d.ImageOrientationPatient.vm)
   for x in values(d.ImageOrientationPatient) do
      print(x)
   end
   
   -- Iterate over Sequences
   
   for i,v in d.SourceImageSequence:ipairs() do
      print(i,v.ReferencedSOPClassUID.value)
   end
   
   -- Insert Items into Sequences
   
   local n = d.SourceImageSequence:length()
   local old = d.SourceImageSequence[1]
   local new = d.SourceImageSequence:insert(n+1)
   new.ReferencedSOPClassUID = old.ReferencedSOPClassUID
   
   print(old.ReferencedSOPClassUID.value, old)
   print(new.ReferencedSOPClassUID.value, new)
   
   -- Remove Items from Sequences
   
   d.SourceImageSequence:remove(n+1)
   local _, err = pcall(function()
         print(new.ReferencedSOPClassUID)
      end)
   print(err)
   
   -- Accessing DICOM Meta-data
   
   local m = d.meta()
   print(m.TransferSyntaxUID.value)
   
   -- Saving DICOM Files
   
   local live = false
   if live then
      d:save('d:\\modified.dcm')
   end
end